@@ -2,18 +2,18 @@ import logging
 
 import fastapi
 import uvicorn
+from image_detection_core.save_model import ModelConverter
 from image_service_foundation.logger import set_logging
 from image_service_foundation.storage.models_provider import ModelsProvider
-from image_detection_core.save_model import Model_Converter
 
 from image_detection_service.api_v1.image_detection_service import (
     example_service_router as router_v1,
 )
 from image_detection_service.constants import (
     API_VERSION_PREFIX,
+    DEFAULT_HOST,
     DEFAULT_LOG_LEVEL,
     DEFAULT_SERVICE_PORT,
-    DEFAULT_HOST,
     PROJECT_DESCRIPTION,
     PROJECT_NAME,
 )
@@ -51,15 +51,15 @@ async def version() -> dict:
 def run_app(port: int = None, log_level: str = None) -> None:
     config = initialize_configuration()
 
-    models_converter = Model_Converter(config)
-    models_provider = ModelsProvider(config,models_converter)
+    models_converter = ModelConverter(config)
+    models_provider = ModelsProvider(config, models_converter)
     models_provider.download_models()
 
-    port = port or config.get('exampletemplateservice.port', DEFAULT_SERVICE_PORT)
-    host = config.get('exampletemplateservice.hostName', DEFAULT_HOST)
-    log_file = config.get('exampletemplateservice.logFile')
+    port = port or config.get('imagedetectionservice.port', DEFAULT_SERVICE_PORT)
+    host = config.get('imagedetectionservice.hostName', DEFAULT_HOST)
+    log_file = config.get('imagedetectionservice.logFile')
     fastapi_log_level = config.get('fastapi.logLevel')
-    log_level = log_level or config.get('exampletemplateservice.logLevel', DEFAULT_LOG_LEVEL)
+    log_level = log_level or config.get('imagedetectionservice.logLevel', DEFAULT_LOG_LEVEL)
 
     set_logging(filepath=log_file, level=log_level, multithreaded=True)
     logging.getLogger('multipart.multipart').setLevel(logging.WARNING)
